<?php

namespace XF2SEO\SEOPackage\Entity;

use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

/**
 * COLUMNS
 * @property int|null redirect_id
 * @property string match_url
 * @property string target_url
 * @property string redirect_type
 * @property bool active
 */
class Redirect extends Entity
{
    public function getRedirectStatus(): int
    {
        if ($this->redirect_type === 'permanently') {
            return 301;
        }

        return 302;
    }

    public static function getStructure(Structure $structure)
    {
        $structure->table = 'xf_seo_package_redirect';
        $structure->primaryKey = 'redirect_id';
        $structure->shortName = 'XF2SEO\SEOPackage:Redirect';

        $structure->columns = [
            'redirect_id' => ['type' => self::UINT, 'nullable' => true, 'autoIncrement' => true],
            'match_url' => ['type' => self::STR, 'maxLength' => 255, 'required' => true],
            'target_url' => ['type' => self::STR, 'maxLength' => 255, 'required' => true],
            'redirect_type' => [
                'type' => self::STR,
                'allowedValues' => ['temporary', 'permanently'],
                'default' => 'temporary'
            ],
            'active' => ['type' => self::BOOL, 'default' => true],
        ];

        return $structure;
    }
}
